@@ -47,8 +47,6 @@
 #include <glib/gstdio.h>
 #include <gmodule.h>
 
-#include <gconf/gconf-client.h>
-
 #include "brasero-units.h"
 
 #include "burn-job.h"
@@ -88,8 +86,9 @@ typedef struct _BraseroWodimPrivate BraseroWodimPrivate;
 
 static GObjectClass *parent_class = NULL;
 
-#define GCONF_KEY_IMMEDIATE_FLAG	"/apps/brasero/config/immed_flag"
-#define GCONF_KEY_MINBUF_VALUE		"/apps/brasero/config/minbuf_value"
+#define BRASERO_SCHEMA_CONFIG		"org.gnome.brasero.config"
+#define BRASERO_KEY_IMMEDIATE_FLAG      "immed-flag"
+#define BRASERO_KEY_MINBUF_VALUE	"minbuf-value"
 
 static BraseroBurnResult
 brasero_wodim_stderr_read (BraseroProcess *process, const gchar *line)
@@ -114,13 +113,13 @@ brasero_wodim_stderr_read (BraseroProcess *process, const gchar *line)
 						BRASERO_BURN_ERROR_MEDIUM_SPACE,
 						_("Not enough space available on the disc")));
 	}
-	else if (strstr (line ,"cdrecord: A write error occured")
+	else if (strstr (line ,"cdrecord: A write error occurred")
 	     ||  strstr (line, "Could not write Lead-in")
 	     ||  strstr (line, "Cannot fixate disk")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_WRITE_MEDIUM,
-						_("An error occured while writing to disc")));
+						_("An error occurred while writing to disc")));
 	}
 	else if (strstr (line, "DMA speed too slow") != NULL) {
 		brasero_job_error (BRASERO_JOB (process),
@@ -276,7 +275,7 @@ brasero_wodim_set_rate (BraseroProcess *process,
                         int speed_1,
                         int speed_2)
 {
-	gdouble current_rate;
+	gdouble current_rate = -1.0;
 	BraseroMedia media;
 
 	if (brasero_job_get_media (BRASERO_JOB (process), &media) != BRASERO_BURN_OK)
@@ -1200,23 +1199,20 @@ brasero_wodim_class_init (BraseroWodimClass *klass)
 static void
 brasero_wodim_init (BraseroWodim *obj)
 {
-	GConfClient *client;
+	GSettings *settings;
 	BraseroWodimPrivate *priv;
 
 	/* load our "configuration" */
 	priv = BRASERO_WODIM_PRIVATE (obj);
 
-	client = gconf_client_get_default ();
-	priv->immediate = gconf_client_get_bool (client,
-						 GCONF_KEY_IMMEDIATE_FLAG,
-						 NULL);
-	priv->minbuf = gconf_client_get_int (client,
-					     GCONF_KEY_MINBUF_VALUE,
-					     NULL);
+	settings = g_settings_new (BRASERO_SCHEMA_CONFIG);
+
+	priv->immediate = g_settings_get_boolean (settings, BRASERO_KEY_IMMEDIATE_FLAG);
+	priv->minbuf = g_settings_get_int (settings, BRASERO_KEY_MINBUF_VALUE);
 	if (priv->minbuf > 95 || priv->minbuf < 25)
 		priv->minbuf = 30;
 
-	g_object_unref (client);
+	g_object_unref (settings);
 }
 
 static void
@@ -1275,6 +1271,7 @@ brasero_wodim_export_caps (BraseroPlugin *plugin)
 	/* NOTE: it seems that cdrecord can burn cue files on the fly */
 	brasero_plugin_define (plugin,
 			       "wodim",
+	                       NULL,
 			       _("Burns, blanks and formats CDs and DVDs"),
 			       "Philippe Rouquier",
 			       0);
@@ -1418,10 +1415,10 @@ brasero_wodim_export_caps (BraseroPlugin *plugin)
 					BRASERO_BURN_FLAG_NONE);
 
 	/* add some configure options */
-	immed = brasero_plugin_conf_option_new (GCONF_KEY_IMMEDIATE_FLAG,
+	immed = brasero_plugin_conf_option_new (BRASERO_KEY_IMMEDIATE_FLAG,
 						_("Enable the \"-immed\" flag (see wodim manual)"),
 						BRASERO_PLUGIN_OPTION_BOOL);
-	minbuf = brasero_plugin_conf_option_new (GCONF_KEY_MINBUF_VALUE,
+	minbuf = brasero_plugin_conf_option_new (BRASERO_KEY_MINBUF_VALUE,
 						 _("Minimum drive buffer fill ratio (in %) (see wodim manual):"),
 						 BRASERO_PLUGIN_OPTION_INT);
 	brasero_plugin_conf_option_int_set_range (minbuf, 25, 95);
